package org.fortiss.tooling.ext.quality.ui;

/*-------------------------------------------------------------------------+
| Copyright 2019 fortiss GmbH                                              |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
import static java.util.Arrays.asList;
import static java.util.Collections.emptyList;
import static org.fortiss.tooling.kernel.ui.service.IContextMenuService.BOTTOM_MOST_MENU_SECTION_ID;

import java.util.List;

import org.eclipse.emf.ecore.EObject;
import org.eclipse.jface.action.Action;
import org.eclipse.jface.action.ActionContributionItem;
import org.eclipse.jface.action.IContributionItem;
import org.eclipse.jface.resource.ImageDescriptor;
import org.fortiss.af3.project.model.FileProject;
import org.fortiss.tooling.ext.quality.service.IModelQualityService;
import org.fortiss.tooling.kernel.extension.data.ITopLevelElement;
import org.fortiss.tooling.kernel.service.IPersistencyService;
import org.fortiss.tooling.kernel.ui.extension.IContextMenuContributor;
import org.fortiss.tooling.kernel.ui.extension.data.ContextMenuContextProvider;

/**
 * Crates a context menu entry to generate the for the selected
 * 
 * @author munaro
 */
public class ModelQualityExtractionMenu implements IContextMenuContributor {

	/** String appearing in the context menu. */
	private static final String MENU_NAME = "Extract metrics";

	/** {@inheritDoc} */
	@Override
	public List<IContributionItem> getContributedItems(EObject selection,
			ContextMenuContextProvider contextProvider) {
		if(!(selection instanceof FileProject)) {
			return emptyList();
		}
		return asList(new IContributionItem[] {
				new ActionContributionItem(new MetricExtractionAction((FileProject)selection))});
	}

	/** {@inheritDoc} */
	@Override
	public String getMenuSectionID() {
		return BOTTOM_MOST_MENU_SECTION_ID;
	}

	/** Returns the icon that is visible in the context menu for this entry. */
	protected ImageDescriptor getActionIcon() {
		return QualityUIActivator.getImageDescriptor("icons/componentarchitecture.gif");
	}

	/** Action for generating the set of . */
	protected class MetricExtractionAction extends Action {

		/** */
		private final FileProject fp;

		/** Constructor. */
		public MetricExtractionAction(FileProject fp) {
			super(MENU_NAME, getActionIcon());
			this.fp = fp;
		}

		/** {@inheritDoc} */
		@Override
		public void run() {
			ITopLevelElement top = IPersistencyService.getInstance().getTopLevelElementFor(this.fp);
			IModelQualityService.getInstance().performMetricAnalysis(top);
		}
	}
}
